@@ -612,8 +612,8 @@ void AI::BattlePlanner::battleBegins()
 {
     _currentTurnNumber = 0;
     _numberOfRemainingTurnsWithoutDeaths = MAX_TURNS_WITHOUT_DEATHS;
-    _attackerForceNumberOfDead = 0;
-    _defenderForceNumberOfDead = 0;
+    _attackerForceTotalNumberOfDeadUnits = 0;
+    _defenderForceTotalNumberOfDeadUnits = 0;
 }
 
 void AI::BattlePlanner::BattleTurn( Battle::Arena & arena, const Battle::Unit & currentUnit, Battle::Actions & actions )
@@ -632,7 +632,7 @@ bool AI::BattlePlanner::isLimitOfTurnsExceeded( const Battle::Arena & arena, Bat
     const PlayerColor currentColor = arena.GetCurrentColor();
 
     // Not the attacker's turn, no further checks
-    if ( currentColor != arena.GetArmy1Color() ) {
+    if ( currentColor != arena.getAttackingArmyColor() ) {
         return false;
     }
 
@@ -641,13 +641,14 @@ bool AI::BattlePlanner::isLimitOfTurnsExceeded( const Battle::Arena & arena, Bat
 
     // This is the beginning of a new turn and we still haven't gone beyond the limit on the number of turns without deaths
     if ( currentTurnNumber > _currentTurnNumber && _numberOfRemainingTurnsWithoutDeaths > 0 ) {
-        auto prevNumbersOfDead = std::tie( _attackerForceNumberOfDead, _defenderForceNumberOfDead );
-        const auto currNumbersOfDead = std::make_tuple( arena.GetForce1().GetDeadCounts(), arena.GetForce2().GetDeadCounts() );
+        auto prevNumbersOfDeadUnits = std::tie( _attackerForceTotalNumberOfDeadUnits, _defenderForceTotalNumberOfDeadUnits );
+        const auto currNumbersOfDeadUnits
+            = std::make_tuple( arena.getAttackingForce().getTotalNumberOfDeadUnits(), arena.getDefendingForce().getTotalNumberOfDeadUnits() );
 
         // Either we don't have numbers of dead units from the previous turn, or there were changes in these numbers compared
         // to the previous turn, reset the counter
-        if ( _currentTurnNumber == 0 || currentTurnNumber - _currentTurnNumber != 1 || prevNumbersOfDead != currNumbersOfDead ) {
-            prevNumbersOfDead = currNumbersOfDead;
+        if ( _currentTurnNumber == 0 || currentTurnNumber - _currentTurnNumber != 1 || prevNumbersOfDeadUnits != currNumbersOfDeadUnits ) {
+            prevNumbersOfDeadUnits = currNumbersOfDeadUnits;
 
             _numberOfRemainingTurnsWithoutDeaths = MAX_TURNS_WITHOUT_DEATHS;
         }
@@ -1051,7 +1052,7 @@ void AI::BattlePlanner::analyzeBattleState( const Battle::Arena & arena, const B
     // Mark as castle siege only if any tower is present. If no towers present then nothing to defend and most likely all walls are destroyed as well.
     if ( castle && Battle::Arena::isAnyTowerPresent() ) {
         const bool attackerIgnoresCover = [&arena]() {
-            const HeroBase * commander = arena.GetForce1().GetCommander();
+            const HeroBase * commander = arena.getAttackingForce().GetCommander();
             assert( commander != nullptr );
 
             if ( commander->GetBagArtifacts().isArtifactBonusPresent( fheroes2::ArtifactBonusType::NO_SHOOTING_PENALTY ) ) {
